pymldb
======

Python interface to the [Machine Learning Database (MLDB)](http://mldb.ai).

[More documentation available on mldb.ai](http://mldb.ai/doc/#builtin/Notebooks.md.html).

## Installation

`pip install pymldb`
